%global major 0
%define libname %mklibname %name %major
%define devname %mklibname -d %name
# Upstream does not maintain a soversion so we define one here.
# abi-compliance-checker will be used to determine if an abi breakage occurs
# and the soversion will be incremented.
%global sover 0.2

%global commit 69b844dc9eea0a014326149c259e7810ecec4c8c
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%global upname OpenCOLLADA

%global uname   openCOLLADA


Name:           opencollada
Version:        0
Release:        %mkrel 2
License:        MIT
Summary:        Collada 3D import and export libraries
Group:          System/Libraries
Url:            https://collada.org/mediawiki/index.php/OpenCOLLADA

Source0:        https://github.com/KhronosGroup/OpenCOLLADA/archive/%{commit}/%{upname}-%{shortcommit}.tar.gz
Source1:        ChangeLog

Patch0:         OpenCOLLADA-cmake.patch
# Add missing COLLADABUURI.h and vector includes
Patch1:         OpenCOLLADA-includes.patch
Patch2:         opencollada-buildfix.diff

BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libpcreposix)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)

%description 
COLLADA is a royalty-free XML schema that enables digital asset
exchange within the interactive 3D industry.
OpenCOLLADA is a Google summer of code opensource project providing
libraries for 3D file interchange between applications like blender.
COLLADABaseUtils          Utils used by many of the other projects
COLLADAFramework          Datamodel used to load COLLADA files
COLLADAStreamWriter       Sources (Library to write COLLADA files)
COLLADASaxFrameworkLoader Library that loads COLLADA files in a sax
                          like manner into the framework data model
COLLADAValidator          XML validator for COLLADA files, based on
                          the COLLADASaxFrameworkLoader
GeneratedSaxParser        Library used to load xml files in the way
                          used by COLLADASaxFrameworkLoader

%package        doc
Summary:        Developer documentation for %{uname}
Group:          Documentation
BuildArch:      noarch

%description doc
This package provides documentation for %{name}.

%package        -n %libname
Summary:        XML schema that enables digital asset exchange
Group:          System/Libraries

%description -n %libname
COLLADA is a royalty-free XML schema that enables digital asset
exchange within the interactive 3D industry.
OpenCOLLADA is a Google summer of code opensource project providing
libraries for 3D file interchange between applications like blender.
COLLADABaseUtils          Utils used by many of the other projects
COLLADAFramework          Datamodel used to load COLLADA files
COLLADAStreamWriter       Sources (Library to write COLLADA files)
COLLADASaxFrameworkLoader Library that loads COLLADA files in a sax
                          like manner into the framework data model
COLLADAValidator          XML validator for COLLADA files, based on
                          the COLLADASaxFrameworkLoader
GeneratedSaxParser        Library used to load xml files in the way
                          used by COLLADASaxFrameworkLoader

%package        -n %devname
Summary:        Include files for openCOLLADA development
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:	openCOLLADA-devel

%description -n %devname
This package provides the include files necessary to build and
develop with the %{uname} export and import libraries.

%package        utils
Summary:        XML validator for COLLADA files
Group:          Development/Tools
Requires:       %{libname} = %{version}-%{release}

%description utils
XML validator for COLLADA files, based on the COLLADASaxFrameworkLoader.


%prep
%setup -q -n %{upname}-%{shortcommit}
%patch0 -p1 -b .cmake
%patch1 -p1 -b .includes
%patch2 -p1 -b .includes

# Remove unused bundled libraries
rm -rf Externals/{Cg,expat,lib3ds,LibXML,MayaDataModel,pcre,zlib,zziplib}

# Add some docs, need to fix eol encoding with dos2unix in some files.
find ./ -name .project -delete
cp -pf COLLADAStreamWriter/README README.COLLADAStreamWriter
cp -pf COLLADAStreamWriter/LICENSE ./

iconv -f ISO_8859-1 -t utf-8 COLLADAStreamWriter/AUTHORS > \
  COLLADAStreamWriter/AUTHORS.tmp
touch -r COLLADAStreamWriter/AUTHORS COLLADAStreamWriter/AUTHORS.tmp
mv COLLADAStreamWriter/AUTHORS.tmp COLLADAStreamWriter/AUTHORS

dos2unix -f -k README.COLLADAStreamWriter
dos2unix -f -k LICENSE
dos2unix -f -k README
find htdocs/ -name *.php -exec dos2unix -f {} \;
find htdocs/ -name *.css -exec dos2unix -f {} \;

# Install Changelog
install -p -m 0644 %{S:1} ./


%build
#rm -rf Build && mkdir -p Build && pushd Build
%cmake -DUSE_STATIC=OFF \
       -DUSE_SHARED=ON \
       -Dsoversion=%{sover} \
       -DCMAKE_SKIP_RPATH=ON \
       -DCMAKE_BUILD_TYPE="RelWithDebInfo"

%make


%install
pushd build
make DESTDIR=%{buildroot} install

# Manually install binary
mkdir -p %{buildroot}%{_bindir}/
install -p -m 0755 bin/* %{buildroot}%{_bindir}/

popd

# Install MathMLSolver headers
mkdir -p %{buildroot}%{_includedir}/MathMLSolver
cp -a Externals/MathMLSolver/include/* %{buildroot}%{_includedir}/MathMLSolver/





%files -n %libname
%doc README LICENSE README.COLLADAStreamWriter COLLADAStreamWriter/AUTHORS
%doc ChangeLog
%{_libdir}/lib*.so.%{sover}

%files doc
%doc htdocs/

%files -n %devname
%{_libdir}/*.so
%{_libdir}/cmake/*
%{_includedir}/*

%files utils
%{_bindir}/*




%changelog
* Fri Nov 14 2014 tv <tv> 0-2.mga5
+ Revision: 797064
- provides openCOLLADA-devel

* Fri Nov 14 2014 tv <tv> 0-1.mga5
+ Revision: 797046
- imported package opencollada

